@@ -198,7 +198,7 @@ class VerifyToken:
                                                       },
                                            many=False)
             if roles:
-                permission_list.extend(roles[0]['permission_status'])  # list类型
+                permission_list.extend(roles[0].get('permission_status', []))  # list类型
                 is_all_data_list.append(roles[0]['is_all_data'])  # 是否开放全部数据
         permission_list = list(set(permission_list))  # 权限值去重
         is_all_data_list = list(set(is_all_data_list))  # 数据权限去重
